/**
 * @file
 * Defines behaviors for the Braintree Drop-in UI payment method form.
 */

(function($) {
    Drupal.behaviors.commerceBraintreeDropin = {
        attach: function (context, settings) {
            if (typeof settings.commerceBraintreeDropin !== 'undefined') {
                var $dropInForm = $(context).find(settings.commerceBraintreeDropin.options.container).once();
                if ($dropInForm.length) {
                    var waitForSdk = setInterval(function () {
                        if (typeof braintree !== 'undefined' && typeof braintree.dropin !== 'undefined') {
                            clearInterval(waitForSdk);
                            var $form = $dropInForm.closest('form');
                            Drupal.braintreeDropIn = new Drupal.commerceBraintreeDropin($form, settings.commerceBraintreeDropin);
                            Drupal.braintreeDropIn.bootstrap();
                        }
                    }, 100);
                }
            }
        }
    };

    Drupal.commerceBraintreeDropin = function ($form, settings) {
        this.settings = settings;
        this.$form = $form;
        this.fromId = this.$form.attr('id');
        this.$submit = this.$form.find('[name=op]');
        this.error = '';
        this.$nonceInput = $('input[name="' + settings.nonceInput +'"]', $form);
        return this;
    };

    Drupal.commerceBraintreeDropin.prototype.bootstrap = function () {
        var button = document.querySelector(Drupal.braintreeDropIn.settings.submitSelector);
        braintree.dropin.create(this.settings.options, function (createErr, instance) {
            button.addEventListener('click', function (e) {
                e.preventDefault();
                instance.requestPaymentMethod(function (requestPaymentMethodErr, payload) {
                    if (requestPaymentMethodErr) {
                        // No payment method is available.
                        // An appropriate error will be shown in the UI.
                        console.error(requestPaymentMethodErr);
                        Drupal.braintreeDropIn.resetSubmitBtn();
                        return;
                    }

                    Drupal.braintreeDropIn.payloadReceived(payload);
                });
            });
        });
    };

    Drupal.commerceBraintreeDropin.prototype.resetSubmitBtn = function () {
        $('.checkout-processing', this.$form).addClass('element-invisible');
        this.$submit.removeAttr('disabled');
        this.$submit.next('.checkout-continue').remove();
        this.$submit.show();
    };

    Drupal.commerceBraintreeDropin.prototype.payloadReceived = function (payload) {
        this.$submit.attr({'disabled' : 'disabled'});
        this.$nonceInput.val(payload.nonce);
        this.$form.submit();
    };
})(jQuery);
